#!/bin/csh -f
# if there's no gfortran here, next line will not include "gcc version"
# and the three GFORTRAN_M..OR_*VERSION envs won't be set, so it should 
# be okay.
# 
# Once I'm happy with this I'll add the Intel compilers as well.
#
if ( $?CLIB == 0 ) then
    echo You must have CCP4 set up first! exiting now
endif
#
# initialize
# 
setenv LC_ALL "C"
setenv BREAKOUTNOW 0
setenv BYTES32OR64 ""
setenv USE_G77 1
setenv USE_IFORT "No"
#
# first test which Fortrans are here - maybe add ifort later
#
# 
foreach I ( gfortran g77 ifort )
#
#
    $I -c test.f >& /dev/null
    set use_${I} = $status
    $I -m32 -c test.f >& /dev/null
    set use_${I}_32 = $status
    $I -m64 -c test.f >& /dev/null
    set use_${I}_64 = $status
end
#
# IFORT exists - assume it's the newest - test to see if it's 
# compatible with $CLIB/libccp4f.a etc
#
if ( $use_ifort == 0 ) then
    set ifort_version = `ifort -v > & junk ; cat junk ; /bin/rm -f junk`
endif 
if ( $use_ifort_32 == 0 ) then
    ifort -m32 -c test.f >& /dev/null
    ifort -m32 test.o $CLIB/libccp4f.a $CLIB/libccp4c.a -o test_exec >& /dev/null
    set use_ifort_32 = $status
    if ( -e test_exec  && $use_ifort_32 == 0 ) then
# this construction prevents "Segmentation fault" appearing on screen
	( ./test_exec && true ) >& /dev/null
	set use_ifort_32 = $status
    endif
    if ( $use_ifort_32 == 0 ) then 
	setenv BYTES32OR64 "-m32"
	unsetenv BREAKOUTNOW
	echo ... looks like an Intel fortran 32-bit build
	set use_ifort_64 = 1
    endif

endif
if ( $use_ifort_64 == 0 ) then
    ifort -m64 -c test.f >& /dev/null
    ifort -m64 test.o $CLIB/libccp4f.a $CLIB/libccp4c.a -o test_exec >& /dev/null
    set use_ifort_64 = $status
    if ( -e test_exec  && $use_ifort_64 == 0 ) then
# this construction prevents "Segmentation fault" appearing on screen
	( ./test_exec && true ) >& /dev/null
	set use_ifort_64 = $status
    endif
    if ( $use_ifort_64 == 0 ) then 
	setenv BYTES64OR64 "-m64"
	unsetenv BREAKOUTNOW
	echo ... looks like an Intel fortran 64-bit build
    endif

endif
if ( $use_ifort_32 == 0 || $use_ifort_64 == 0 ) then
    set use_gfortran = 1
    set use_g77 = 1
else
    set use_ifort = 1
endif
# if we can use ifort with the currently used CCP4 libraries, make sure we don't test 
# anything for gfortran or g77


#
# GFORTRAN exists, test version etc -----------------------------------------
#
if ( $use_gfortran == 0 ) then 
    set gfortran_version = `gfortran -v > & junk ; grep 'gcc version' junk | awk '{print $3}' ; /bin/rm -f junk`
    set GFORTRAN_MAJOR_VERSION = `echo $gfortran_version | cut -c1`
    set GFORTRAN_MINOR_VERSION = `echo $gfortran_version | cut -c3`
    set GFORTRAN_MINOR_SUBVERSION = `echo $gfortran_version | cut -c5`
    if ( $GFORTRAN_MINOR_VERSION < 1 ) then 
	echo your gfortran is too old, cannot use gfortran
	set use_gfortran = 1
    endif
#
# 
    if ( $GFORTRAN_MINOR_VERSION < 2 ) then
    echo Your installed version of gfortran is not reliable - you should update to
    echo a version no older than 4.2.0, and preferably the newest stable version.
    unsetenv BREAKOUTNOW
    endif


#
# this gfortran is new enough, test for CCP4 libraries built as 32-bit objects 
# with gfortran
#
    if ( $use_gfortran_32 == 0 ) then
	gfortran -m32 -c test.f >& /dev/null
	gfortran -m32 test.o $CLIB/libccp4f.a $CLIB/libccp4c.a -o test_exec >& /dev/null
	set use_gfortran_32 = $status
	if ( -e test_exec  && $use_gfortran_32 == 0 ) then
    # this construction prevents "Segmentation fault" appearing on screen
	    ( ./test_exec && true ) >& /dev/null
	    set use_gfortran_32 = $status
	endif
	if ( $use_gfortran_32 == 0 ) then 
	    setenv BYTES32OR64 "-m32"
	    unsetenv BREAKOUTNOW
	    echo ... looks like a gfortran 32-bit build
	    set use_gfortran_64 = 1
	endif
    endif
#
# or are the CCP4 libraries 64-bit?
#
    if ( $use_gfortran_64 == 0 ) then
	gfortran -m64 -c test.f >& /dev/null
	gfortran -m64 test.o $CLIB/libccp4f.a $CLIB/libccp4c.a -o test_exec >& /dev/null
	set use_gfortran_64 = $status
	if ( -e test_exec  && $use_gfortran_32 == 0 ) then
    # this construction prevents "Segmentation fault" appearing on screen
	    ( ./test_exec && true ) >& /dev/null
	    set use_gfortran_64 = $status
	endif
	if ( $use_gfortran_64 == 0 ) then 
	    setenv BYTES32OR64 "-m64"
	    unsetenv BREAKOUTNOW
	    echo ... looks like a gfortran 64-bit build
	endif
    endif
    if ( $use_gfortran_32 == 0 || $use_gfortran_64 == 0 ) then
	set use_ifort = 1
	set use_g77 = 1
    else
	set use_gfortran = 1
    endif

endif
#
# G77 exists, test version etc -----------------------------------------
#
# test for CCP4 libraries built as 32-bit objects 
# with g77
#
if ( $use_g77 == 0) then
    set g77_version = `g77 -v > & junk ; grep 'gcc version' junk | awk '{print $3}' ; /bin/rm -f junk`
#
# some g77s (even 3.4, where it is normally found) don't have the "-m32" flag.
# if it doesn't have the -m32 flag, it shouldn't have the -m64 flag either
    g77 -m32 -c test.f >& /dev/null
    set no_m32_flag = $status
    if ( $no_m32_flag == 0 ) then 
	setenv BYTES32OR64 "-m32"
    else
	setenv BYTES32OR64 ""
	unsetenv BREAKOUTNOW
    endif

    if ( $use_g77_32 == 0 ) then
	g77 $BYTES32OR64 -c test.f >& /dev/null
	g77 $BYTES32OR64 test.o $CLIB/libccp4f.a $CLIB/libccp4c.a -o test_exec >& /dev/null
	set use_g77_32 = $status
	if ( -e test_exec  && $use_g77_32 == 0 ) then
# this construction prevents "Segmentation fault" appearing on screen
	    ( ./test_exec && true ) >& /dev/null
	    set use_g77_32 = $status
	endif
	if ( $use_g77_32 == 0 ) then 
	    setenv BYTES32OR64 "-m32"
	    unsetenv BREAKOUTNOW
	    echo ... looks like a g77 32-bit build
	    set use_g77_64 = 1
	endif
    endif
#
# or are the CCP4 libraries 64-bit?
#
    if ( $use_g77_64 == 0 ) then
	g77 -m64 -c test.f >& /dev/null
	g77 -m64 test.o $CLIB/libccp4f.a $CLIB/libccp4c.a -o test_exec >& /dev/null
	set use_g77_64 = $status
	if ( -e test_exec  && $use_g77_32 == 0 ) then
    # this construction prevents "Segmentation fault" appearing on screen
	    ( ./test_exec && true ) >& /dev/null
	    set use_g77_64 = $status
	endif
	if ( $use_g77_64 == 0 ) then 
	    setenv BYTES32OR64 "-m64"
	    unsetenv BREAKOUTNOW
	    echo ... looks like a g77 64-bit build
	endif
    endif
    if ( $use_g77_32 == 0 || $use_g77_64 == 0 ) then
	set use_ifort = 1
	set use_gfortran = 1
    else
	set use_g77 = 1
    endif
endif
#
# Now assign compiler and linker flags 
#
# summarize the success of trying ifort
#
if ( $use_ifort == 0 ) then
    echo Your Intel Fortran ifort works with your CCP4 libraries, so we are building with 
    echo ifort $ifort_version
#    echo `which ifort`
    setenv F77 "`which ifort` ${BYTES32OR64}"
    setenv FC "${F77}"
    setenv CC "`which icc` ${BYTES32OR64}"
    setenv FLINK "${F77}"
    setenv USE_IFORT "YES"
endif
#
# summarize the success of trying gfortran
#
if ( $use_gfortran == 0 ) then
    echo Your gfortran works with your CCP4 libraries, so we are building with 
    echo gfortran version $gfortran_version
    echo `which gfortran`
    setenv F77 "`which gfortran` ${BYTES32OR64}"
    setenv FC "${F77}"
    setenv CC "${F77}"
    setenv FLINK "${F77}"
endif
#
# summarize the success of trying g77
#
if ( $use_g77 == 0 ) then
    echo Your g77 works with your CCP4 libraries, so we are building with 
    echo g77 version $g77_version
    echo `which g77`
    setenv F77 "`which g77` ${BYTES32OR64}"
    setenv FC "${F77}"
    setenv CC "${F77}"
    setenv FLINK "${F77} -lg2c"
    setenv USE_G77 0
endif
    echo These are the compilation and linking programs:
    echo F77 is    $F77
    echo FC  is    $FC
    echo CC  is    $CC
    echo Linker is $FLINK
if ( -e a.out ) then
    /bin/rm -f a.out
endif

